/*================================================================================*/
/* @(#)Rev.1.12 - tstgidadc.c                                                     */
/* GID-ADC Test Program for PC-UNIX.  (Only 'root' can perform this.)             */
/* Copyright 1996-2003(C) by Mathematical Assist Design Lab.,all rights reserved. */
/* Copyright 1999-2003(C) by Masahiko Watanabe,all rights reserved.               */
/*                                                                                */
/* This Program should be compiled with 'gidadcctl.c' as follows.                 */
/*      # cc -otstgidadc -O2 tstgidadc.c gidadcctl.c                              */
/*      # chmod 700 tstgidadc                                                     */
/*                                                                                */
/* Usage : tstgidadc [-pPORTNO ] [-fPATHNAME ] [-nTIMES ] [-u] [-b]               */
/*           PORTNO   : ComPort No. (1 to 4)                                      */
/*           PATHNAME : PathName(Max128Bytes) to be Text-output(CSV).             */
/*           TIMES    : Number of Times to Measure.                               */
/*            -u      : Unipola Mode.                                             */
/*            -b      : Bipola Mode.                                              */
/*            -h      : Display Help Massage.                                     */
/*            -?      : Display Help Massage. (Not fot FreeBSD)                   */
/*================================================================================*/

#include  "gidadcctl.h"

#define  MJ_VER        1       /* Major Version. */
#define  MN_VER        13      /* Minor Version. */
#define  DEF_COMPORT   1       /* Default COM Port No. to be used (1 to 4) */
#define  DEF_TIMES     20      /* Default Times to Measure with GID-ADC. */
#define  MAX_PATH_LEN  128     /* Max PathName Length to be output.  */
#define  DEF_POLA      UNIPOLA /* Default Pola Mode. (UNIPOLA or BIPOLA) */

#include  <stdio.h>
/* #include  <conio.h>  not used in PC-UNIX. #*/
#include  <stdlib.h>
#include  <string.h>
#include  <time.h>

/*===============================================*/
char     Fname[256] ;
FILE    *Fp ;
unsigned long Times ;
int      Pola ;
/*===============================================*/

void  test( void )
{
  int p,  c ;
  int buf[8] ;
  time_t t_start ;
  time_t t_end ;
  unsigned long i ;

  printf( "\nStart GID-ADC Mesuring, press CTRL+C to end.\n" ) ;
  printf( "Comport:%d (I/O Address 0x%3x)\n", ComPort, PtoA( ComPort )) ;
  printf( "Measure %lu Times\n", Times ) ; 
  switch( Pola )
    {
    case UNIPOLA :
      printf( "Mode : UNIPOLA\n" ) ;
      break ;
    case BIPOLA :
      printf( "Mode : BIPOLA\n" ) ;
      break ;
    default :
      fprintf( stderr, "Error : Illegal 'Mode' (0x%x) specified.\n", Pola ) ;
      break ;
    }
  GbInit() ;
  GbInitPower() ;
  GbSetPola( Pola ) ;
  GbSetTrigaNone() ;
  GbSetTWait( 16L * 3600L ) ;

#define MCH 7

#ifdef DEBUG
/* Dummy Read for Stable. */ 
  for(p=0; p<=MCH; p++) 
     {
     GbSetCh( p ) ;
     buf[p] = GbCnv() ;
     }
#endif

  time( &t_start ) ;
  time( &t_end   ) ;
  for ( i = 0L; i < Times; i++ )
    {
    for(p=0; p<=MCH; p++) 
       {
       GbSetCh( p ) ;
       buf[p] = GbCnv() ;
       }
    printf("\n %10ld, %5d, %5d, %5d, %5d, %5d, %5d, %5d, %5d",
            i+1L, buf[0], buf[1], buf[2], buf[3], buf[4], buf[5], buf[6], buf[7]);

    if ( Fp != NULL )
       fprintf(Fp, "\n %10ld, %5d, %5d, %5d, %5d, %5d, %5d, %5d, %5d",
            i+1L, buf[0], buf[1], buf[2], buf[3], buf[4], buf[5], buf[6], buf[7]);
retry: ;
    time( &t_end ) ;
    sleep(1);
    t_start = t_end ;
    }
  if ( Fp != NULL )
     {
     fprintf( Fp, "\n" ) ;
     fclose( Fp ) ;
     }
  GbFree() ;
  printf( "\n" ) ;
}


void Copyright( void )
{
  printf( "\ntstgidadc Version %1d.%02d - Test Program for GID-ADC on PC-UNIX.\n", MJ_VER, MN_VER ) ;
  printf( "Copyright 1996-2003 (C) by Mathematical Assist Design Lab.,all rights reserved.\n" ) ;
  printf( "Copyright 1999-2003 (C) by Masahiko Watanabe,all rights reserved.\n" ) ;
  printf( "Copyright 2000 (C) by Yukio Mitsuiwa,all rights reserved.\n" ) ;

}


void Usage( void )
{
  printf( "\nUsage : tstgidadc [-pPORTNO ] [-fPATHNAME ] [-nTIMES ] [-u] [-b] [-?]\n" ) ;
  printf( "  PORTNO   : ComPort No. (1 to 4)\n" ) ;
  printf( "  PATHNAME : PathName(Max128Bytes) to be Text-output(CSV).\n" ) ;
  printf( "  TIMES    : Number of Times to Measure.\n" ) ; 
  printf( "   -u      : Unipola Mode.\n" ) ;
  printf( "   -b      : Bipola Mode.\n" ) ;
  printf( "   -h      : Show this Help.\n" ) ;
  printf( "   -?      : Show this Help. (Not for FreeBSD)\n" ) ;
  printf( "(If no option specified, default is ComPort:%d, Times:%ld, UNIPOLA.)\n\n",
                            DEF_COMPORT, DEF_TIMES ) ;
  printf( "\nExample : tstgidadc -p1 -fdata.csv -n20 -b\n" ) ;
}


int  main ( int argc, char *argv[] )
{
  Times = DEF_TIMES ;
  ComPort = DEF_COMPORT ;
  Pola = DEF_POLA ;

  Copyright() ;

  for( ; argc > 1 ; ) /* Any Option ? */
     {
     argc--;
     switch( *argv[argc] )
       {
       case  '-': /* Option Specified ? */
           switch( *(argv[argc] + 1))
             {
             case  'p': /* ComPort No. Specified. */
               switch( *(argv[argc] + 2 ))
                 {
                 case  '1':
                 case  '2':
                 case  '3':
                 case  '4':
                        ComPort = *(argv[argc] + 2) - '0';
                        goto next_args ;
                 default  :
                     fprintf( stderr, "\nError : Illegal ComPort No.(%s) Specified. It should be (1 to 4).\n", argv[argc]+2 ) ;
                     Usage() ;
                     return( 1 ) ;
                 }
               break ;
             case  'f' :  /* Text-Output File Specified. */
               strncpy( Fname, argv[argc] + 2, MAX_PATH_LEN ) ;
               if (( Fp = fopen( Fname, "w" )) == NULL )
                   {
                   fprintf( stderr, "\nError : Cannot Open Output File(%s).\n", Fname ) ;
                   Usage() ;
                   return( 1 ) ;
                   }
                goto next_args ;
             case 'n' :  /* Times to Measure value Specified. */
               Times = 0L ;
               sscanf(argv[argc] + 2, "%lu",  &Times ) ;
               if ( Times == 0L )
                  {
                  fprintf( stderr, "\nError : Illegal option specified : '%s'.\n", argv[argc] ) ;
                  Usage() ;
                  return( 1 ) ;
                  }
               goto next_args ;
             case 'b' :
               Pola = BIPOLA ;
               goto next_args ;
             case 'u' :
               Pola = UNIPOLA ;
               goto next_args ;
             case 'h' :
             case '?' :
               Usage() ;
               return( 1 ) ;
             default  :
               fprintf( stderr, "\nError : Illegal option specified : '%s'.\n", argv[argc] ) ;
               Usage() ;
               return( 1 ) ;
             }
       default  :
         fprintf( stderr, "\nError : Illegal option specified : '%s'.\n", argv[argc] ) ;
         Usage() ;
         return( 1 ) ;
       }
next_args : ;
     }
  setlinebuf(stdout); 
  test() ;
  return( 0 ) ;
}


/*==========================*/
/*   End  of  tstgidadc.c   */
/*==========================*/
